@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, see
- * <http://www.gnu.org/licenses/>.
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifndef _BABL_EXTENSION_H
@@ -22,13 +22,13 @@
 
 /****************************************************************/
 /* BablExtension */
-BABL_NAMED_CLASS_DECLARE (extension);
+BABL_CLASS_DECLARE (extension);
 /*
  * BablExtension objects are only used internally in babl.
  */
 
-Babl * babl_extension (const char *name);
-
+const  Babl * babl_extension               (const char *name);
+void          babl_extension_load_dir_list (const char *dir_list);
 
 typedef struct
 {
