@@ -145,11 +145,12 @@ max_path_length (void)
   if (env)
     max_length = atoi (env);
   else
-    max_length = 3; /* reducing this number makes finding short fishes much
+    max_length = 2; /* reducing this number makes finding short fishes much
                        faster - even if we lose out on some of the fast
-                       bigger fish, the fishes we can get with a max_length of 3
-                       is actually 5, since we deepen the search twice if no
-                       sufficient results are found.
+                       bigger fish, the fishes we can get with a max_length of 2
+                       is actually 5, since we deepen the search to that
+                       depth if none are found within two steps in the
+                       initial search.
                      */
   if (max_length > BABL_HARD_MAX_PATH_LENGTH)
     max_length = BABL_HARD_MAX_PATH_LENGTH;
@@ -351,85 +352,85 @@ alias_conversion (Babl *babl,
   {
     if ((conv->source->format.space == sRGB) &&
         (conv->destination->format.space == sRGB))
-  {
-    switch (conv->instance.class_type)
     {
-      case BABL_CONVERSION_LINEAR:
-       babl_conversion_new (
-              babl_format_with_space (
-                    (void*)conv->source->instance.name, (void*)space),
-              babl_format_with_space (
-                    (void*)conv->destination->instance.name, (void*)space),
-              "linear", conv->function.linear,
-              "data", conv->data,
-              NULL);
-        break;
-      case BABL_CONVERSION_PLANAR:
-       babl_conversion_new (
-              babl_format_with_space (
-                    (void*)conv->source->instance.name, (void*)space),
-              babl_format_with_space (
-                    (void*)conv->destination->instance.name, (void*)space),
-              "planar", conv->function.planar,
-              "data", conv->data,
-              NULL);
-        break;
-      case BABL_CONVERSION_PLANE:
-        babl_conversion_new (
-              babl_format_with_space (
-                    (void*)conv->source->instance.name, (void*)space),
-              babl_format_with_space (
-                    (void*)conv->destination->instance.name, (void*)space),
-              "plane", conv->function.plane,
-              "data", conv->data,
-              NULL);
-        break;
-      default:
-        break;
+      switch (conv->instance.class_type)
+      {
+        case BABL_CONVERSION_LINEAR:
+         babl_conversion_new (
+                babl_format_with_space (
+                      (void*)conv->source->instance.name, (void*)space),
+                babl_format_with_space (
+                      (void*)conv->destination->instance.name, (void*)space),
+                "linear", conv->function.linear,
+                "data", conv->data,
+                NULL);
+          break;
+        case BABL_CONVERSION_PLANAR:
+         babl_conversion_new (
+                babl_format_with_space (
+                      (void*)conv->source->instance.name, (void*)space),
+                babl_format_with_space (
+                      (void*)conv->destination->instance.name, (void*)space),
+                "planar", conv->function.planar,
+                "data", conv->data,
+                NULL);
+          break;
+        case BABL_CONVERSION_PLANE:
+          babl_conversion_new (
+                babl_format_with_space (
+                      (void*)conv->source->instance.name, (void*)space),
+                babl_format_with_space (
+                      (void*)conv->destination->instance.name, (void*)space),
+                "plane", conv->function.plane,
+                "data", conv->data,
+                NULL);
+          break;
+        default:
+          break;
+      }
     }
   }
-  }
   else
   if ((conv->source->class_type == BABL_MODEL) &&
       (conv->destination->class_type == BABL_MODEL))
   {
     if ((conv->source->model.space == sRGB) &&
         (conv->destination->model.space == sRGB))
-  {
-    switch (conv->instance.class_type)
     {
-      case BABL_CONVERSION_LINEAR:
-        babl_conversion_new (
-              babl_remodel_with_space (
-                    (void*)conv->source, (void*)space),
-              babl_remodel_with_space (
-                    (void*)conv->destination, (void*)space),
-              "linear", conv->function,
-              NULL);
-        break;
-      case BABL_CONVERSION_PLANAR:
-        babl_conversion_new (
-              babl_remodel_with_space (
-                    (void*)conv->source, (void*)space),
-              babl_remodel_with_space (
-                    (void*)conv->destination, (void*)space),
-              "planar", conv->function,
-              NULL);
-        break;
-      case BABL_CONVERSION_PLANE:
-        babl_conversion_new (
-              babl_remodel_with_space (
-                    (void*)conv->source, (void*)space),
-              babl_remodel_with_space (
-                    (void*)conv->destination, (void*)space),
-              "plane", conv->function,
-              NULL);
-        break;
-      default:
-        break;
+      switch (conv->instance.class_type)
+      {
+        case BABL_CONVERSION_LINEAR:
+          babl_conversion_new (
+                babl_remodel_with_space (
+                      (void*)conv->source, (void*)space),
+                babl_remodel_with_space (
+                      (void*)conv->destination, (void*)space),
+                "linear", conv->function.linear,
+                NULL);
+          break;
+        case BABL_CONVERSION_PLANAR:
+          babl_conversion_new (
+                babl_remodel_with_space (
+                      (void*)conv->source, (void*)space),
+                babl_remodel_with_space (
+                      (void*)conv->destination, (void*)space),
+                "planar", conv->function.planar,
+                NULL);
+          break;
+        case BABL_CONVERSION_PLANE:
+          babl_conversion_new (
+                babl_remodel_with_space (
+                      (void*)conv->source, (void*)space),
+                babl_remodel_with_space (
+                      (void*)conv->destination, (void*)space),
+                "plane", conv->function.plane,
+                NULL);
+          break;
+        default:
+          break;
+      }
     }
   }
-  }
   else
   if ((conv->source->class_type == BABL_TYPE) &&
       (conv->destination->class_type == BABL_TYPE))
@@ -453,7 +454,8 @@ _babl_fish_prepare_bpp (Babl *babl)
          babl->fish_path.source_bpp = babl_source->type.bits / 8;
          break;
        default:
-         babl_log ("=eeek{%i}\n", babl_source->instance.class_type - BABL_MAGIC);
+         babl_log ("=eeek{%i}\n",
+			  babl_source->instance.class_type - BABL_MAGIC);
      }
 
    switch (babl_dest->instance.class_type)
@@ -507,6 +509,15 @@ babl_fish_path2 (const Babl *source,
   const Babl *sRGB = babl_space ("sRGB");
   char name[BABL_MAX_NAME_LEN];
   int is_fast = 0;
+  static int debug_missing = -1;
+  if (debug_missing < 0)
+  {
+     const char *val = getenv ("BABL_DEBUG_MISSING");
+     if (val && strcmp (val, "0"))
+       debug_missing = 1;
+     else
+       debug_missing = 0;
+  }
 
   _babl_fish_create_name (name, source, destination, 1);
   babl_mutex_lock (babl_format_mutex);
@@ -586,8 +597,13 @@ babl_fish_path2 (const Babl *source,
   babl->fish_path.cost            = BABL_MAX_COST_VALUE;
   babl->fish_path.conversion_list = babl_list_init_with_size (BABL_HARD_MAX_PATH_LENGTH);
 
+
   {
     PathContext pc;
+    int start_depth = max_path_length ();
+    int end_depth = start_depth + 2 + ((destination->format.space != sRGB)?1:0);
+    end_depth = MIN(end_depth, BABL_HARD_MAX_PATH_LENGTH);
+
     pc.current_path = babl_list_init_with_size (BABL_HARD_MAX_PATH_LENGTH);
     pc.fish_path = babl;
     pc.to_format = (Babl *) destination;
@@ -599,52 +615,25 @@ babl_fish_path2 (const Babl *source,
      */
     babl_in_fish_path++;
 
-    get_conversion_path (&pc, (Babl *) source, 0, max_path_length (), tolerance);
-
-#if 0
-    /* second attempt,. at path length + 1*/
-    if (babl->fish_path.conversion_list->count == 0 &&
-        max_path_length () + 1 <= BABL_HARD_MAX_PATH_LENGTH)
+    for (int max_depth = start_depth;
+         babl->fish_path.conversion_list->count == 0 && max_depth <= end_depth;
+         max_depth++)
     {
-      get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 1, tolerance);
-
-#if 0
-      if (babl->fish_path.conversion_list->count)
-      {
-        fprintf (stderr, "babl is using a rather long chain, room exists for optimization here\n");
-        babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
-      }
-#endif
+      get_conversion_path (&pc, (Babl *) source, 0, max_depth, tolerance);
     }
-#endif
 
-    /* third attempt,. at path length + 2 */
-    if (babl->fish_path.conversion_list->count == 0 &&
-        max_path_length () + 2 <= BABL_HARD_MAX_PATH_LENGTH)
+    if (debug_missing)
     {
-      get_conversion_path (&pc, (Babl *) source, 0, max_path_length () + 2, tolerance);
-#if 1
-      if (babl->fish_path.conversion_list->count)
-      {
-        //fprintf (stderr, "babl is a long chain, should be optimized\n");
-        //babl_list_each (babl->fish_path.conversion_list, show_item, NULL);
-      }
+      if (babl->fish_path.conversion_list->count == 0)
+        fprintf (stderr, "babl: WARNING lacking conversion path for %s to %s\n",
+          babl_get_name (source), babl_get_name (destination));
+      else if (babl->fish_path.conversion_list->count == end_depth)
+        fprintf (stderr, "babl: WARNING need %i step conversion for %s to %s\n", end_depth,
+          babl_get_name (source), babl_get_name (destination));
       else
-      {
-         static int show_missing = -1;
-         if (show_missing < 0)
-         {
-            const char *val = getenv ("BABL_DEBUG_MISSING");
-            if (val && strcmp (val, "0"))
-              show_missing = 1;
-            else
-              show_missing = 0;
-         }
-         if (show_missing)
-           fprintf (stderr, "babl is lacking conversion for %s to %s\n",
-               babl_get_name (source), babl_get_name (destination));
-      }
-#endif
+        fprintf (stderr, "babl: found %i step conversion for %s to %s\n",
+          babl->fish_path.conversion_list->count,
+          babl_get_name (source), babl_get_name (destination));
     }
 
     babl_in_fish_path--;
@@ -656,11 +645,6 @@ babl_fish_path2 (const Babl *source,
       babl_free (babl);
       babl_mutex_unlock (babl_format_mutex);
 
-      /* it is legitimate for reference paths to be faster than long chains
-         of paths, thus it is time to retire this warning. XXX: remove it fully 
-
-          _babl_fish_missing_fast_path_warning (source, destination); */
-
       return NULL;
     }
 
